@@ -9,7 +9,4 @@
 #ifndef _KLIBC_ARCHCONFIG_H
 #define _KLIBC_ARCHCONFIG_H
 
-/* We have an MMU but no fork() syscall */
-#define _KLIBC_NO_MMU 0
-
 #endif				/* _KLIBC_ARCHCONFIG_H */
