@@ -14,9 +14,6 @@
 
 #define _KLIBC_STATFS_F_TYPE_64 1
 
-/* We can use RT signals on MIPS */
-#define _KLIBC_USE_RT_SIG 1
-
 /* MIPS has architecture-specific code for vfork() */
 #define _KLIBC_REAL_VFORK 1
 
