@@ -9,17 +9,22 @@
 #define _KLIBC_ARCHSIGNAL_H
 
 #include <asm/signal.h>
+
+#ifndef _NSIG
+
 #define _NSIG    64
 #define _NSIG_SZ (_NSIG / LONG_BIT)
 
 typedef struct {
-        unsigned long sig[_NSIG_SZ];
+	unsigned long sig[_NSIG_SZ];
 } sigset_t;
 
+#endif /* _NSIG */
+
 struct sigaction {
-        __sighandler_t sa_handler;
-        unsigned long sa_flags;
-        sigset_t sa_mask;
+	__sighandler_t	sa_handler;
+	unsigned long	sa_flags;
+	sigset_t	sa_mask;
 };
 
 #endif
