@@ -9,7 +9,4 @@
 #ifndef _KLIBC_ARCHCONFIG_H
 #define _KLIBC_ARCHCONFIG_H
 
-/* Use rt_* signals */
-#define _KLIBC_USE_RT_SIG 1
-
 #endif				/* _KLIBC_ARCHCONFIG_H */
