@@ -107,6 +107,8 @@
 #define AT_CLKTCK 	17	/* frequency at which times() increments */
 /* 18..22 = ? */
 #define AT_SECURE 	23	/* secure mode boolean */
+#define AT_SYSINFO	32	/* vdso entry point address */
+#define AT_SYSINFO_EHDR	33	/* vdso header address */
 
 /* Program header permission flags */
 #define PF_X            0x1
@@ -147,6 +149,9 @@
 #define SHN_COMMON      0xfff2
 #define SHN_HIRESERVE   0xffff
 
+/* End of a chain.  */
+#define STN_UNDEF	0
+
 /* Lenght of magic at the start of a file */
 #define EI_NIDENT	16
 
