@@ -3,8 +3,8 @@
 
 struct iovec;
 
-int packet_open(void);
-void packet_close(void);
+int packet_open(struct netdev *dev);
+void packet_close(struct netdev *dev);
 int packet_send(struct netdev *dev, struct iovec *iov, int iov_len);
 void packet_discard(struct netdev *dev);
 int packet_recv(struct netdev *dev, struct iovec *iov, int iov_len);
