@@ -7,8 +7,6 @@
 #include <sys/types.h>
 #include "malloc.h"
 
-#if !_KLIBC_NO_MMU		/* uClinux doesn't have brk() */
-
 char *__current_brk;
 
 /*
@@ -25,5 +23,3 @@ int brk(void *end_data_segment)
 	__current_brk = new_brk;
 	return 0;
 }
-
-#endif
