@@ -1,8 +1,8 @@
 /*
  * fork.c
  *
- * This is normally just a syscall stub, but at least one system
- * doesn't have sys_fork, only sys_clone...
+ * This is normally just a syscall stub, but new architectures only
+ * implement clone().
  */
 
 #include <sys/syscall.h>
@@ -11,11 +11,11 @@
 #include <sched.h>
 #include <klibc/sysconfig.h>
 
-#if !_KLIBC_NO_MMU && !defined(__NR_fork)
+#ifndef __NR_fork
 
 pid_t fork(void)
 {
 	return __clone(SIGCHLD, 0);
 }
 
-#endif				/* __NR_fork */
+#endif
