@@ -32,18 +32,20 @@ int inet_pton(int af, const char *src, void *dst)
 	case AF_INET6:
 		{
 			struct in6_addr *d = (struct in6_addr *)dst;
-			int colons = 0, dcolons = 0;
+			int colons = 0, dcolons = 0, digits = 0;
 			int i;
 			const char *p;
 
 			/* A double colon will increment colons by 2,
 			   dcolons by 1 */
-			for (p = dst; *p; p++) {
+			for (p = src; *p; p++) {
 				if (p[0] == ':') {
 					colons++;
 					if (p[1] == ':')
 						dcolons++;
-				} else if (!isxdigit(*p))
+					digits = 0;
+				} else if (!isxdigit((unsigned char)*p)
+					   || ++digits > 4)
 					return 0;	/* Invalid address */
 			}
 
@@ -54,7 +56,7 @@ int inet_pton(int af, const char *src, void *dst)
 			memset(d, 0, sizeof(struct in6_addr));
 
 			i = 0;
-			for (p = dst; *p; p++) {
+			for (p = src; *p; p++) {
 				if (*p == ':') {
 					if (p[1] == ':') {
 						i += (8 - colons);
